function pltcal (xi,yi,zi,stn,titre)

% Fonction qui permet de tracer les rsultats de l'interpolation 
% objective des donnes de biologie du Georges Bank sur une carte
% avec des contours de couleur.
%
% Limite de la transformation: (-72.5; 40)  (-65; 43) degrs
% Zro de la carte: -67.8

% Minimum et maximum de zi

  zimin = round(min(min(zi))*10)/10;
  zimax = round(max(max(zi))*10)/10;
  dzi   = (zimax - zimin)/10;

% Masquage
  
  load masque.dat
  masq = flipud(masque);
  zi = zi .* masq;

% Trace le contour en couleur

  figure
  subplot ('Position',[0.1 0.3 0.8 0.5])
  colormap(jet(128))
  hfi = app_int (xi*1000,yi*1000,zi,25,'pcolor');
  caxis ([zimin zimax])
  hold on

% Trace la cte et la bathymtrie

  load bathutm
  plot (utmcote(:,1),utmcote(:,2),'g','linewidth',0.8)
  plot (utm060(:,1),utm060(:,2),'w','LineWidth',0.2)
  plot (utm100(:,1),utm100(:,2), 'w','LineWidth',0.2)
  plot (utm200(:,1),utm200(:,2),'w','LineWidth',0.2)

% Trace les station d'chantionnage

  plot (stn(:,1),stn(:,2),'w.','MarkerSize',11)
 
% Arrange la proportion des axes

  ax = [-350000 200000 4450000 4750000];
  axis (ax)
  set (gca,'aspectratio',[(ax(2)-ax(1))/(ax(4)-ax(3)) 1]) 
  text (0.5,1.1,titre,'Units','normalized','HorizontalAlignment',...
        'center','VerticalAlignment','bottom','FontSize',16)

% Trace le cadre

  set (gca,'Visible','off')
  plot ([ax(1) ax(2)],[ax(3) ax(3)],'w')
  plot ([ax(1) ax(2)],[ax(4) ax(4)],'w')
  plot ([ax(1) ax(1)],[ax(3) ax(4)],'w')
  plot ([ax(2) ax(2)],[ax(3) ax(4)],'w')

% Trace l'chelle de couleur

  subplot ('Position',[0.2 0.2 0.6 0.04])
  colormap(jet(128))
  caxis ([zimin zimax])
  hfi = app_int ([zimin:dzi/100:zimax],[1,2],[zimin:dzi/100:zimax;zimin:dzi/100:zimax],1,'pcolor'); 
  caxis ([zimin zimax])
  set (gca,'YTickLabels',[])%,'XTick',(zimin:2*dzi:zimax))
  set (gca,'Xlim',[zimin,zimax])